from django.conf import settings
from django.core.mail import send_mail
from django.views.generic import CreateView
from django.views.generic import DeleteView
from django.views.generic import UpdateView

from study_registration.studies.mixins import StudyAspectMixin

from .forms import PublicationForm
from .models import Publication


class PublicationCreateView(StudyAspectMixin, CreateView):
    model = Publication
    form_class = PublicationForm

    def send_notification(self):
        text = self.object.text()
        user = self.request.user.get_full_name()
        link = self.request.build_absolute_uri(self.study.get_absolute_url())

        subject = settings.EMAIL_SUBJECT_PREFIX + 'New publication'
        body = f'{user} registered a new publication:\n\n{text}\n\n{link}'
        to = settings.PUBLICATION_NOTIFICATIONS_TO

        return send_mail(subject, body, None, to)

    def form_valid(self, form):
        form.instance.study = self.study
        response = super().form_valid(form)
        self.send_notification()
        return response


class PublicationUpdateView(StudyAspectMixin, UpdateView):
    model = Publication
    form_class = PublicationForm


class PublicationDeleteView(StudyAspectMixin, DeleteView):
    model = Publication
