from django.http import JsonResponse
from django.shortcuts import get_object_or_404
from django.views.generic import View

from .models import Link
from .models import Study


def serialize_department(department):
    if department:
        return {
            'name': department.name,
        }


def serialize_user(user):
    if user:
        return {
            'username': user.username,
            'first_name': user.first_name,
            'last_name': user.last_name,
            'email': user.email,
        }


def serialize_study(request, study):
    return {
        'id': str(study),
        'url': request.build_absolute_uri(study.get_absolute_url()),
        'created_at': study.created_at,
        'updated_at': study.updated_at,
        'owners': [serialize_user(owner) for owner in study.owners.all()],
        'title': study.title,
        'short_title': study.short_title,
        'aliases': study.aliases,
        'end': study.end,
        'description': study.description,
        'department': serialize_department(study.department),
        'website_urls': [link.url for link in study.link_set.filter(type=Link.WEBSITE)],
        'prereg_urls': [link.url for link in study.link_set.filter(type=Link.PREREG)],
        'data_urls': [link.url for link in study.link_set.filter(type=Link.DATA)],
        'code_urls': [link.url for link in study.link_set.filter(type=Link.CODE)],
        'contact_person': serialize_user(study.contact_person),
        'affiliated_scientists': study.affiliated_scientists,
        'keywords': [keyword.name for keyword in study.keyword_set.all()],
    }


class StudyApiView(View):
    def get(self, request, **kwargs):
        study = get_object_or_404(
            Study, pk=self.kwargs['pk'], short_title=self.kwargs['slug']
        )
        return JsonResponse(serialize_study(request, study))
