from django.contrib import admin
from django.contrib.auth.views import LoginView
from django.contrib.auth.views import LogoutView
from django.urls import include
from django.urls import path
from django.views.generic import RedirectView
from django.views.generic import TemplateView
from django.views.i18n import JavaScriptCatalog

from study_registration.budgets.views import BudgetListView
from study_registration.deployments.api import DeploymentsApiView
from study_registration.deployments.views import DeploymentListView

urlpatterns = [
    path('', RedirectView.as_view(pattern_name='studies:list'), name='index'),
    path('about/', TemplateView.as_view(template_name='about.html'), name='about'),
    path(
        'contact/', TemplateView.as_view(template_name='contact.html'), name='contact'
    ),
    path('login/', LoginView.as_view(), name='login'),
    path('logout/', LogoutView.as_view(), name='logout'),
    path('admin/', admin.site.urls),
    path('jsi18n/', JavaScriptCatalog.as_view(), name='javascript-catalog'),
    path('theme.css', TemplateView.as_view(
        template_name='bootstrap_theme.css', content_type='text/css'
    ), name='bootstrap-theme'),
    path(
        'studies/<int:study_pk>-<slug:study_short>/publications/',
        include('study_registration.publications.urls', namespace='publications'),
    ),
    path(
        'studies/<int:study_pk>-<slug:study_short>/datasets/',
        include('study_registration.datasets.urls', namespace='datasets'),
    ),
    path(
        'studies/<int:study_pk>-<slug:study_short>/budgets/',
        include('study_registration.budgets.urls', namespace='budgets'),
    ),
    path(
        'studies/<int:study_pk>-<slug:study_short>/deployments/',
        include('study_registration.deployments.urls', namespace='deployments'),
    ),
    path('studies/', include('study_registration.studies.urls', namespace='studies')),
    path('budgets/', BudgetListView.as_view(), name='budget-list'),
    path('deployments/', DeploymentListView.as_view(), name='deployment-list'),
    path('api/deployments/', DeploymentsApiView.as_view(), name='deployment-api'),
]

try:
    import debug_toolbar

    urlpatterns += [
        path('__debug__/', include(debug_toolbar.urls)),
    ]
except ImportError:
    pass
